@@ -1,16 +1,15 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 import typer
-
-from snowcli import config, utils
+from snowcli import config
 from snowcli.config import AppConfig
-from snowcli.snowsql_config import SnowsqlConfig
 from snowcli.utils import print_db_cursor
 
 app = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]})
 EnvironmentOption = typer.Option("dev", help='Environment name')
 
+
 @app.command("status")
 def warehouse_status(environment: str = EnvironmentOption):
     """
@@ -24,5 +23,6 @@ def warehouse_status(environment: str = EnvironmentOption):
             database=env_conf.get('database'),
             schema=env_conf.get('schema'),
             role=env_conf.get('role'),
-            warehouse=env_conf.get('warehouse'))
+            warehouse=env_conf.get('warehouse'),
+        )
         print_db_cursor(results, ['name', 'state', 'queued', 'resumed_on'])
