@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import sys
 
 
@@ -5,9 +7,10 @@ def hello() -> str:
     return 'Hello World!'
 
 
-# For local debugging. Be aware you may need to type-convert arguments if you add input parameters
+# For local debugging. Be aware you may need to type-convert arguments if
+# you add input parameters
 if __name__ == '__main__':
     if len(sys.argv) > 1:
         print(hello(sys.argv[1:]))  # type: ignore
     else:
-        print(hello()) # type: ignore
+        print(hello())  # type: ignore
